@@ -90,7 +90,7 @@ class GeoArray(object):
         if isinstance(path_or_array, str):
             assert ' ' not in path_or_array, "The given path contains whitespaces. This is not supported by GDAL."
 
-            if not os.path.exists(path_or_array):
+            if not os.path.exists(path_or_array) and not path_or_array.startswith('/vsi'):
                 raise FileNotFoundError(path_or_array)
 
         if isinstance(path_or_array, GeoArray) or issubclass(getattr(path_or_array, '__class__'), GeoArray):
